// @ts-nocheck

var licenseFileFullPath = '';
var currentLicenseData;

$(function () {

  /* === Activate JRebel Dialog STARTS === */

  const addLicense = $("#button-add-license");
  const activateModal = $("#activate-modal");
  const activateModalCancel = $("#button-cancel-activate-modal");
  const activateModalOk = $("#button-ok-activate-modal");

  addLicense.click(() => {
    activateModal.css('display', 'block');
  });

  const closeModal = function () {
    activateModal.css('display', 'none');
  };

  const onTabChange = function (titleId) {
    activateModalOk.prop('disabled', !$('#agree-terms').is(':checked'));
    if (titleId === "commercial-license-tab-title") {
      // commercial license tab has always two buttons
      $("#agree-terms-section").removeClass("displaynone");
      $("#button-ok-activate-modal").removeClass("displaynone");
    } else if (titleId === "individual-trial-tab-title") {
      // hide OK button and TOS agreement checkbox only when trial is active or expired
      if (currentLicenseData) {
        if (currentLicenseData.isTrialTabAvailable && (currentLicenseData.trialExpirationText || currentLicenseData.trialActivatedText)) {
          $("#agree-terms-section").addClass("displaynone");
          $("#button-ok-activate-modal").addClass("displaynone");
        }
        else if (currentLicenseData.isTrialTabAvailable && currentLicenseData.isOfflineRegistration) {
          $("#agree-terms-section").addClass("displaynone");
          activateModalOk.prop('disabled', !$('#trial-activation-code-text').val());
        }
      }
    }
  };

  activateModalCancel.click(handleCancel);

  bindTabAndContent(activateModal, 'commercial-license-tab-title', 'commercial-license-tab-content', 'have-commercial-license', true, onTabChange);
  bindTabAndContent(activateModal, 'individual-trial-tab-title', 'individual-trial-tab-content', 'have-commercial-license', false, onTabChange);

  function radioSelectionChanged() {
    $('[name="license-src"]').each((_, radio) => {
      $('#' + radio.id + '-div').find('input, textarea, button').prop('disabled', !radio.checked);
    });
  }

  $('[name="license-src"]').change(radioSelectionChanged);

  $('#team-url').prop('checked', true); //TODO set according to the business logic
  radioSelectionChanged();

  $('#browse-license-file').click(() => {
    vscode.postMessage({ handlerId: 'licenses', type: 'openFileDialog' });
  });


  $('#agree-terms').click(e => {
    activateModalOk.prop('disabled', !e.target.checked);
  });

  $('#trial-activation-code-text').on('input', () => {
    activateModalOk.prop('disabled', !$('#trial-activation-code-text').val());
  });

  function scrollToDialogTop() {
    $("#activate-modal .modal-dialog")[0].scroll({ top: 0, behavior: 'smooth' });
  }

  function handleOK() {
    const values = {};
    activateModal.find('input, textarea').each((_, input) => {
      values[input.id] = input.value;
    });
    activateModal.find('input[type="checkbox"], input[type="radio"]').each((_, input) => {
      values[input.id] = input.checked;
    });

    values['license-file-input'] = licenseFileFullPath;
    values['offline-activation-form'] = !$('#offline-activation-form').hasClass('displaynone');

    let infomessage = $("#activationdialog-infomessage");
    infomessage.removeClass("displaynone");
    infomessage.addClass("blue");
    infomessage.html("Activating...");
    scrollToDialogTop();
    vscode.postMessage({ handlerId: 'licenses', type: 'activateModalOK', values: values });
  }

  activateModalOk.click(handleOK);

  function handleCancel() {
    resetLicenseDialog();
    if (currentLicenseData) {
      fillLicenseDialog(currentLicenseData);
    }
    closeModal();
  }

  function resetLicenseDialog() {
    $('#license-dialog-data-form')[0].reset();
    $("#activationdialog-infomessage").addClass('displaynone');
    $("#trial-activated-form").removeClass("displaynone");
    $("#offline-activation-form").removeClass("displaynone");
    $("#trial-activated-message-container").addClass("displaynone");
    $("#trial-activated-message-greenlabel").removeClass("displaynone");
    $("#individual-trial-tab-title").removeClass("displaynone");
    $("#individual-trial-tab-content").removeClass("displaynone");
    licenseFileFullPath = '';
    activateModalOk.prop('disabled', true);
  }

  function fillLicenseDialog(data) {
    $('#' + data.tab1SelectedRadio).click();
    let vMap = data.tab1InputValues;
    for (const key in vMap) {
      if (vMap.hasOwnProperty(key)) {
        let el = $('#' + key);
        if (key === "license-file-input") {
          el.val(vMap[key].filename);
          el.prop('title', vMap[key].path);
          el.prop('disabled', false);
          licenseFileFullPath = vMap[key].path;
        } else if (el.prop('tagName') === "INPUT") {
          el.val(vMap[key]);
        } else if (el.prop('tagName') === "TEXTAREA") {
          el.html(vMap[key]);
        }
      }
    }

    if (data.tab1ExpirationText) {
      const activationDialogInfoMessage = $("#activationdialog-infomessage");
      activationDialogInfoMessage.removeClass("displaynone");
      activationDialogInfoMessage.html(data.tab1ExpirationText);
    }

    if (data.isTrialTabAvailable) {
      if (data.trialExpirationText || data.trialActivatedText) {
        $("#trial-activated-form").addClass("displaynone");
        $("#offline-activation-form").addClass("displaynone");
        $("#trial-activated-message-container").removeClass("displaynone");
        // not hiding "agree-terms-section" and "button-ok-activate-modal" here because first tab will be selected by default.

        if (data.trialExpirationText) {
          $("#trial-activated-message-greenlabel").addClass("displaynone");
          $("#trial-activated-message-text").html(data.trialExpirationText);
        } else if (data.trialActivatedText) {
          $("#trial-activated-message-greenlabel").html("JRebel activated.");
          $("#trial-activated-message-text").html(data.trialActivatedText);
        }
      } else {
        // just show the trial activation form as it is.
        $("#trial-activated-form").toggleClass("displaynone", data.isOfflineRegistration);
        $("#offline-activation-form").toggleClass("displaynone", !data.isOfflineRegistration);
        if (data.isOfflineRegistration) {
          $("#offline-activation-form a").attr("href", data.offlineLink);
        }
      }
    } else {
      console.log("hiding trial tab");
      $("#individual-trial-tab-title").addClass("displaynone");
      $("#individual-trial-tab-content").addClass("displaynone");
    }
  }

  /* === Activate JRebel Dialog ENDS === */

  $(window).on('message', $e => {
    const event = $e.originalEvent;
    const message = event.data; // The json data that the extension sent
    console.log("licenses.js got event from extension. " + message.type);
    switch (message.type) {
      case 'ui.updateLicenseData':
        {
          currentLicenseData = message.data;

          // TODO update elements in for loop. Iterate over json data element names -> ... -> PROFIT
          if (currentLicenseData.isValidLicense) {
            $("#licenses-licenseType").html(message.data.licenseType);
            $("#licenses-licenseSource").html(message.data.licenseSource);
            $("#licenses-licensedTo").html(message.data.licensedTo);
            $("#button-add-license").html("Change License");
          }

          // prefill activation dialog
          const data = message.data;
          fillLicenseDialog(data);

          if (data.tab1ExpirationText) {
            scrollToDialogTop();

            const licensesSectionInfoMessage = $("#licenses-titleMsg");
            licensesSectionInfoMessage.removeClass().addClass("section-title-msg failure-title-msg");
            licensesSectionInfoMessage.html("JRebel license has expired.");
          }

          if (!data.isValidLicense && !data.tab1ExpirationText) {
            const licenseInfoMsg = $("#licenses-titleMsg");
            licenseInfoMsg.removeClass().addClass("section-title-msg info-title-msg");
            licenseInfoMsg.html("Enter a Valid JRebel License");
          }

          break;
        }
      case 'ui.handleActivateLicenseLicensingStatus':
        {
          console.log("licenses.js got handleActivateLicenseLicensingStatus event. data: " + message.data);
          console.log(message.data);
          let infomessage = $("#activationdialog-infomessage");
          if (message.data.errorMessage) {
            infomessage.removeClass("displaynone");
            infomessage.removeClass("blue");
            infomessage.html(message.data.errorMessage);
            scrollToDialogTop();
          } else if (message.data.license && message.data.license.valid) {
            infomessage.addClass("displaynone");

            // show "JRebel activated" on panel only once
            const licensesSectionInfoMessage = $("#licenses-titleMsg");
            licensesSectionInfoMessage.removeClass().addClass("section-title-msg success-title-msg");
            licensesSectionInfoMessage.html("JRebel Activated");

            // trigger Dashboard update as well. TODO JR-11672 doesn't work???
            vscode.postMessage({ handlerId: 'licenses', type: 'licensesLoaded' });

            closeModal(); // close the activationdialog
          }
          break;
        }
      case 'ui.setLicenseFile':
        {
          const licenseFileInput = $('#license-file-input');
          licenseFileInput.val(event.data.file);
          licenseFileInput.prop('title', event.data.path);
          licenseFileFullPath = event.data.path;
        }
        break;
    }
  });

  console.log("licenses.js loaded");
  vscode.postMessage({ handlerId: 'licenses', type: 'licensesLoaded' });

});