// @ts-nocheck

let dlgRemoteServerId = undefined;

$(function () {

  const configureServerModal = $("#configure-server-modal");

  $('#remoteservers-table-body').on('click', 'toggle-switch', e => {
    const serverId = parseInt($(e.currentTarget).attr('aria-remoteserver-id'));
    const enabled = $(e.currentTarget).prop('checked');
    vscode.postMessage({ handlerId: 'remoteserver', type: 'setSyncEnabled', serverId: serverId, enabled: enabled });
  });

  $('#enable-all-remote-remoteservers').on('click', e => {
    const enabled = $(e.currentTarget).prop('checked');
    const serverIds = $.map($('#remoteservers-table-body .cloned toggle-switch'), (elem) => parseInt($(elem).attr('aria-remoteserver-id')));
    vscode.postMessage({ handlerId: 'remoteserver', type: 'setSyncEnabledForAll', serverIds: serverIds, enabled: enabled });
  });

  $('#remoteservers-table-body').on('click', '.in-table-edit', e => {
    const serverId = parseInt($(e.currentTarget).attr('aria-remoteserver-id'));
    vscode.postMessage({ handlerId: 'remoteserver', type: 'openConfigureServerDialog', serverId: serverId });
  });

  $('#add-remoteserver').on('click', e => {
    vscode.postMessage({ handlerId: 'remoteserver', type: 'startAddingRemoteServer' });
  });

  $('#synchronize-on-build').on('change', e => {
    const enabled = $('#synchronize-on-build').prop('checked');
    vscode.postMessage({ handlerId: 'remoteserver', type: 'synchronizeOnBuildChanged', enabled: enabled });
  });

  function updateSyncServerToggle(server) {
    $(`#remoteservers-table-body .cloned toggle-switch[aria-remoteserver-id="${server.id}"]`).prop('checked', server.syncEnabled);
  }

  function updateSyncAllToggle() {
    const notCheckedCount = $('#remoteservers-table-body .cloned toggle-switch').filter((_, t) => !$(t).prop('checked')).length;
    $('#enable-all-remote-remoteservers').prop('checked', notCheckedCount === 0);
  }

  //=== / Server dialog \ ===

  $('#button-cancel-configure-server-modal').on('click', e => {
    configureServerModal.css('display', 'none');
  });

  $('#button-ok-configure-server-modal').on('click', e => {
    const isNew = dlgRemoteServerId === undefined;
    const serverConf = createServerConfFromUI();
    if (isNew) {
      vscode.postMessage({ handlerId: 'remoteserver', type: 'addRemoteServer', server: serverConf });
    }
    else {
      serverConf.id = dlgRemoteServerId;
      vscode.postMessage({ handlerId: 'remoteserver', type: 'editRemoteServer', server: serverConf });
    }
  });

  configureServerModal.find('input[type="checkbox"]').on('change', e => {
    const id = $(e.currentTarget).attr('id');
    const checked = $(e.currentTarget).prop('checked');
    $(`#${id}-fields`).toggleClass('displaynone', !checked);
    $(`#${id}-spacer`).toggleClass('displaynone', checked);
  });

  $('#button-delete-server').on('click', e => {
    vscode.postMessage({ handlerId: 'remoteserver', type: 'deleteRemoteServer', serverId: dlgRemoteServerId });
  });

  $('#test-remoteserver-connection').on('click', e => {
    $('#test-remoteserver-connection').prop('disabled', true);
    vscode.postMessage({ handlerId: 'remoteserver', type: 'testConnection', server: createServerConfFromUI() });
  });

  function createServerConfFromUI() {
    return {
      name: $('#remoteserver-name').val(),
      url: $('#remoteserver-url').val(),
      useServerAuthentication: $('#server-authentication').prop('checked'),
      serverAuthenticationPassword: $('#server-authentication-password').val(),
      useHttpBasicAuthentication: $('#http-basic-authentication').prop('checked'),
      httpBasicAuthenticationUser: $('#http-basic-authentication-user').val(),
      httpBasicAuthenticationPassword: $('#http-basic-authentication-password').val()
    };
  }

  //=== \ Server dialog / ===

  $(window).on('message', $e => {
    const event = $e.originalEvent;
    switch (event.data.type) {
      case 'updateRemoteServers':
        {
          if (event.data.closeDialog) {
            dlgRemoteServerId = undefined;
            configureServerModal.css('display', 'none');
          }
          const serversTableBody = $("#remoteservers-table-body");
          serversTableBody.find(".cloned").remove();
          if (event.data.servers.length) {
            $('#no-remoteservers-row').css('display', 'none');
            for (let server of event.data.servers) {
              const serverRow = $('#--template-remoteserver-row').clone();
              serverRow.prop('id', `rs-${server.id}-remoteserver-row`);
              serverRow.html(serverRow.html()
                .replace(/--template-remoteserver/g, server.id)
                .replace(/--TEMPLATE-REMOTESERVER-NAME/g, server.name || '')
                .replace(/--TEMPLATE-REMOTESERVER-URL/g, server.url)
              );
              serverRow.find('toggle-switch').prop('checked', server.syncEnabled);
              serverRow.css('display', 'table-row');
              serverRow.addClass("cloned");
              serversTableBody.append(serverRow);
            }
            $('#enable-all-remote-remoteservers').prop('checked', event.data.servers.filter(s => !s.syncEnabled).length === 0);
            $('#enable-all-remote-remoteservers').prop('disabled', false);
            //            bindProjectRows();
          } else {
            $('#no-remoteservers-row').css('display', 'table-row');
            $('#enable-all-remote-remoteservers').prop('checked', false);
            $('#enable-all-remote-remoteservers').prop('disabled', true);
          }
        }
        break;
      case 'updateSynchronizeOnBuild':
        {
          $('#synchronize-on-build').prop('checked', event.data.enabled);
        }
        break;
      case 'updateRemoteServerSyncEnabled':
        {
          const server = event.data.server;
          updateSyncServerToggle(server);
          updateSyncAllToggle();
        }
        break;
      case 'updateRemoteServerSyncEnabledForForAll':
        {
          const servers = event.data.servers;
          for (let server of servers) {
            updateSyncServerToggle(server);
          }
          updateSyncAllToggle();
        }
        break;
      case 'openConfigureServerDialog':
        {
          const server = event.data.server;
          const isNew = server.id === undefined;

          configureServerModal.find('.info-message').toggleClass('displaynone', true);
          $('#test-remoteserver-connection').prop('disabled', false);

          dlgRemoteServerId = server.id;
          $('#remoteserver-name').val(server.name);
          $('#remoteserver-url').val(server.url);

          $('#server-authentication').prop('checked', server.useServerAuthentication);
          $('#server-authentication-password').val(server.serverAuthenticationPassword);
          $('#server-authentication-fields').toggleClass('displaynone', !server.useServerAuthentication);
          $('#server-authentication-spacer').toggleClass('displaynone', server.useServerAuthentication);

          $('#http-basic-authentication').prop('checked', server.useHttpBasicAuthentication);
          $('#http-basic-authentication-user').val(server.httpBasicAuthenticationUser);
          $('#http-basic-authentication-password').val(server.httpBasicAuthenticationPassword);
          $('#http-basic-authentication-fields').toggleClass('displaynone', !server.useHttpBasicAuthentication);
          $('#http-basic-authentication-spacer').toggleClass('displaynone', server.useHttpBasicAuthentication);

          configureServerModal.find('h1').text(isNew ? 'Add Server' : 'Edit Server');
          $('#button-delete-server').toggleClass('displaynone', isNew);

          configureServerModal.css('display', 'block');
        }
        break;
      case 'showDialogError':
        {
          const message = event.data.message;
          if (message) {
            configureServerModal.find('.info-message')
              .text(message)
              .toggleClass('red', true)
              .toggleClass('blue', false)
              .toggleClass('displaynone', false);
          }
          else {
            configureServerModal.find('.info-message')
              .toggleClass('displaynone', true);
          }
          $('#test-remoteserver-connection').prop('disabled', false);
        }
        break;
      case 'testRemoteServerConnectionResponse':
        {
          const message = event.data.message;
          configureServerModal.find('.info-message')
            .text(message)
            .toggleClass('red', !event.data.success)
            .toggleClass('blue', event.data.success)
            .toggleClass('displaynone', false);
          $('#test-remoteserver-connection').prop('disabled', !event.data.finished);
        }
        break;
    }
  });

  vscode.postMessage({ handlerId: 'remoteserver', type: 'remoteserversShown' });

});